<?php

if (get_option('dsv_telephone_validation')) {
	add_filter( 'wpcf7_validate_tel', 'validate_telephone_datasoap_number_cf7', 10, 2 );
	add_filter( 'wpcf7_validate_tel*', 'validate_telephone_datasoap_number_cf7', 10, 2 );
	add_filter( 'wpcf7_validate_intl_tel', 'validate_telephone_datasoap_number_cf7', 10, 2 );
	add_filter( 'wpcf7_validate_intl_tel*', 'validate_telephone_datasoap_number_cf7', 10, 2 );
}

function validate_telephone_datasoap_number_cf7($result, $tag) {
	$tag = new WPCF7_FormTag( $tag );
	$name = $tag->name;
	$sanitisedNumber = '';

	if(isset($_POST[$name])){
		$sanitisedNumber = sanitize_text_field($_POST[$name]);
	}

	$number = $sanitisedNumber;

	// Check if required
	if ( $tag->is_required() && '' == $name ) 
		$result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
	elseif ( '' != $name) {
		$dsv_token = get_option('dsv_token');

		if($dsv_token != "")
		{
			$params = array(
				'lookup' => $number,
				'checks' => array (
					'Auto'
				)
			);

			$apiResult = sendDataSoapValidationRequest($params, $dsv_token);

			if(!isset($apiResult['valid'])){
				$result->invalidate( $tag, "Please enter a valid phone number" );
				return $result;
			}

			if ($apiResult['valid'] == false || $apiResult['valid'] == true && isset($apiResult['errors']))
				$result->invalidate( $tag, "Please enter a valid phone number" );
		}
		else{
			$params = array(
				'lookup' => $number,
				'checks' => array (
					'Syntax'
				)
			);

			$apiResult = sendDataSoapValidationRequest($params, "");

			if(!isset($apiResult['valid'])){
				$result->invalidate( $tag, "Please enter a valid phone number" );
				return $result;
			}

			if ($apiResult['valid'] == false && !isset($apiResult['errors']))
				$result->invalidate( $tag, "Please enter a valid phone number" );
		}
	}
	return $result;
}

if (get_option('dsv_email_validation')) {
	add_filter( 'wpcf7_validate_email', 'validate_email_address_datasoap_cf7', 10, 2 );
	add_filter( 'wpcf7_validate_email*', 'validate_email_address_datasoap_cf7', 10, 2 );
}

function validate_email_address_datasoap_cf7($result, $tag) {
	$tag = new WPCF7_FormTag( $tag );
	$name = $tag->name;
	$sanitisedEmail = '';
	
	if(isset($_POST[$name])){
		$sanitisedEmail = sanitize_email($_POST[$name]);
	}

	$email = $sanitisedEmail;

	if ( $tag->is_required() && '' == $email ) 
		$result->invalidate( $tag, wpcf7_get_message( 'invalid_required' ) );
	elseif ( '' != $email) {
		$dsv_token = get_option('dsv_token');
		
		if($dsv_token != "")
		{
			$params = array(
				'lookup' => $email,
				'checks' => array (
					'Email'
				)
			);

			$apiResult = sendDataSoapValidationRequest($params, $dsv_token);

			if(!isset($apiResult['valid'])){
				$result->invalidate( $tag, "Please enter a valid email address");
				return $result;
			}

			if ($apiResult['valid'] == false)
				$result->invalidate( $tag, "Please enter a valid email address");
		}
		else{
			//If there's no token do a syntax check
			$params = array(
				'lookup' => $email,
				'checks' => array (
					'Syntax'
				)
			);

			$apiResult = sendDataSoapValidationRequest($params, "");

			if(!isset($apiResult['valid'])){
				$result->invalidate( $tag, "Please enter a valid email address");
				return $result;
			}

			if ($apiResult['valid'] == false)
				$result->invalidate( $tag, "Please enter a valid email address");
		}
	}
	return $result;
}
?>