<?php
// create custom plugin settings menu
add_action('admin_menu', 'dsv_create_menu');
add_action('admin_init', 'register_dsvsettings');
add_action('admin_notices', 'add_datasoap_settings_errors');

function dsv_create_menu() {
	add_menu_page("Data Soap Validation", "DS Validate", "administrator", "dsv_value_setting-panel", "dsv_settings_page", "dashicons-phone", 66);
}

function register_dsvsettings() {
	register_setting('dsv-settings-group', 'dsv_password');
	register_setting('dsv-autosettings-group', 'dsv_token');
	register_setting('dsv-autosettings-group', 'dsv_telephone_validation');
	register_setting('dsv-autosettings-group', 'dsv_email_validation');
	register_setting('dsv-autosettings-group', 'dsv_error');
}

function dsv_settings_page() {
	include('includes/dsv_header.php');
	include('includes/dsv_settings.php');
	include('includes/dsv_instructions.php');
	include('includes/dsv_footer.php');	
}

function dsv_settings_link($links) { 
  $settings_link = "<a href=\"admin.php?page=dsv_value_setting-panel\">Settings</a>"; 
  array_unshift($links, $settings_link); 
  return $links; 
}

// display default admin notice - e.g. Saved Successfully!
function add_datasoap_settings_errors() {
    settings_errors();
}

function sendDataSoapValidationRequest($data, $bearerToken) {
	$encodedBody = json_encode($data);
	
	//Use WP to make the API Request
	$response = wp_remote_post( 'https://api.datasoap.co.uk/v2',
		array(
			'headers' => array (
				'Content-Type' => 'application/json',
				'Authorization' => "Bearer {$bearerToken}",
				'Lib-Version' => 'WordPress-1.0.6'
			),
			'body' => $encodedBody,
			'timeout' => 60
		));


	//Check if it errored, if so return that error
	if(is_wp_error($response)) {
		$error_message = $response->get_error_message();
		return $error_message;
	}

	$body = wp_remote_retrieve_body($response);
	$decodedBody = json_decode($body, true);
	return $decodedBody;
}

function dsv_password_changing() {
	$sanitisedToken = sanitize_text_field($_POST['dsv_token']);
	$sanitisedEmailValidation = sanitize_text_field($_POST['dsv_email_validation']);
	$sanitisedPhoneValidation = sanitize_text_field($_POST['dsv_telephone_validation']);


	update_option('dsv_token', $sanitisedToken);
	update_option('dsv_error', "");

	// adjust stored validation variables based on check box values
	update_option('dsv_email_validation', $sanitisedEmailValidation);
	update_option('dsv_telephone_validation', $sanitisedPhoneValidation);

	return "";
}

add_filter("pre_update_option_dsv_password", 'dsv_password_changing', 10, 2);

require_once plugin_dir_path(__FILE__) . '/includes/dsvcf7-validation.php';
require_once plugin_dir_path(__FILE__) . '/includes/dsvwc-validation.php';
require_once plugin_dir_path(__FILE__) . '/includes/dsvgf-validation.php';
require_once plugin_dir_path(__FILE__) . '/includes/dsvwpf-validation.php';
require_once plugin_dir_path(__FILE__) . '/includes/dsvep-validation.php';